NOAA JetStream - Home

# NOAA JetStream

Cloud Data Management System

# Welcome to NOAA JetStream

Cloud data management platform for Google Cloud Storage operations, analytics, and workflow management.

## Quick Actions

📤

### Upload Data

Transfer local folders to Google Cloud Storage

📋

### Job Dashboard

Monitor and manage all upload jobs

📊

### Analytics

View trends and storage statistics

📚

### API Documentation

Interactive REST API reference

## System Status

### Total Jobs

0
All time

### Active Jobs

0
Running now

### Data Uploaded

0 GB
Total transferred

### Queue Length

0
Waiting jobs

## 📚 Resources

### 🪣 NOAA Cloud Data Buckets

- • PIFSC
- • AFSC
- • SWFSC
- • NEFSC
- • NWFSC

### 🔗 Quick Links

- • Google Cloud Console
- • API Documentation
- • Application Settings

### 🚀 Quick Start

1. Authenticate with Google Cloud
2. Create an upload job
3. Monitor progress
4. View analytics